<?php

namespace Drupal\user_dashboard_bootstrap\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\user_dashboard_bootstrap\UserDashboardBlocks;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure User dashboard Bootstrap settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Name of the config.
   *
   * @var string
   */
  public static $configName = 'user_dashboard.settings';

  /**
   * Service user dashboard blocks.
   *
   * @var \Drupal\user_dashboard_bootstrap\UserDashboardBlocks
   */
  private $userDashboardBlocks;

  /**
   * Constructs a \Drupal\system\ConfigFormBase object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\user_dashboard_bootstrap\UserDashboardBlocks $user_dashboard_blocks
   *   The service of userdashboard.
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function __construct(ConfigFactoryInterface $config_factory, UserDashboardBlocks $user_dashboard_blocks) {
    parent::__construct($config_factory);
    $this->userDashboardBlocks = $user_dashboard_blocks;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('user_dashboard_bootstrap.blocks'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'user_dashboard_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [self::$configName];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(self::$configName);
    $blocks = $this->userDashboardBlocks->listBlocks();
    $valuesBlock = $config->get('user_dashboard_available_blocks');

    $form['link'] = [
      '#type' => 'link',
      '#title' => $this->t('Configuration user dashboard by role'),
      '#url' => Url::fromRoute('user_dashboard_bootstrap.set_default'),
    ];
    $form['user_dashboard_available_blocks'] = [
      '#title' => $this->t('Available blocks'),
      '#type' => 'checkboxes',
      '#multiple' => TRUE,
      '#options' => $blocks,
      '#default_value' => !empty($valuesBlock) ? $valuesBlock : [],
      '#description' => $this->t('Choose blocks that can be used on the user dashboard pages.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config(self::$configName)
      ->set('user_dashboard_available_blocks', array_diff($form_state->getValue('user_dashboard_available_blocks'), [0]))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
